@@ -16,4 +16,9 @@ class ovk:
     @staticmethod
     def chicken_wings(client):
         response = http.get(f'https://{client["instance"]}/method/Ovk.chickenWings?access_token={client["token"]}')
+        return json.loads(response.text)
+ 
+     @staticmethod
+    def about_instance(client):
+        response = http.get(f'https://{client["instance"]}/method/Ovk.aboutInstance?access_token={client["token"]}')
         return json.loads(response.text)
\ No newline at end of file
